==> aws-solutions-constructs.aws-eventbridge-stepfunctions-2.12.0.tar.gz: aws-solutions-constructs.aws-eventbridge-stepfunctions-2.12.0/setup.py <==
import json
import setuptools

kwargs = json.loads(
    """
{
    "name": "aws-solutions-constructs.aws-eventbridge-stepfunctions",
    "version": "2.12.0",
    "description": "CDK Constructs for deploying AWS Events Rule that invokes AWS Step Functions",
    "license": "Apache-2.0",
    "url": "https://github.com/awslabs/aws-solutions-constructs.git",
    "long_description_content_type": "text/markdown",
    "author": "Amazon Web Services",
    "bdist_wheel": {
        "universal": true
    },
    "project_urls": {
        "Source": "https://github.com/awslabs/aws-solutions-constructs.git"
    },
    "package_dir": {
        "": "src"
    },
    "packages": [
        "aws_solutions_constructs.aws_eventbridge_stepfunctions",
        "aws_solutions_constructs.aws_eventbridge_stepfunctions._jsii"
    ],
    "package_data": {
        "aws_solutions_constructs.aws_eventbridge_stepfunctions._jsii": [
            "aws-eventbridge-stepfunctions@2.12.0.jsii.tgz"
        ],
        "aws_solutions_constructs.aws_eventbridge_stepfunctions": [
            "py.typed"
        ]
    },
    "python_requires": "~=3.7",
    "install_requires": [
        "aws-cdk-lib>=2.25.0, <3.0.0",
        "aws-solutions-constructs.core==2.12.0",
        "constructs>=10.0.0, <11.0.0",
        "jsii>=1.62.0, <2.0.0",
        "publication>=0.0.3"
    ],
    "classifiers": [
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: JavaScript",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Typing :: Typed",
        "License :: OSI Approved"
    ],
    "scripts": []
}
"""
)

with open("README.md", encoding="utf8") as fp:
    kwargs["long_description"] = fp.read()


setuptools.setup(**kwargs)

==> aws-solutions-constructs.aws-eventbridge-stepfunctions-2.13.0.tar.gz: aws-solutions-constructs.aws-eventbridge-stepfunctions-2.13.0/setup.py <==
import json
import setuptools

kwargs = json.loads(
    """
{
    "name": "aws-solutions-constructs.aws-eventbridge-stepfunctions",
    "version": "2.13.0",
    "description": "CDK Constructs for deploying AWS Events Rule that invokes AWS Step Functions",
    "license": "Apache-2.0",
    "url": "https://github.com/awslabs/aws-solutions-constructs.git",
    "long_description_content_type": "text/markdown",
    "author": "Amazon Web Services",
    "bdist_wheel": {
        "universal": true
    },
    "project_urls": {
        "Source": "https://github.com/awslabs/aws-solutions-constructs.git"
    },
    "package_dir": {
        "": "src"
    },
    "packages": [
        "aws_solutions_constructs.aws_eventbridge_stepfunctions",
        "aws_solutions_constructs.aws_eventbridge_stepfunctions._jsii"
    ],
    "package_data": {
        "aws_solutions_constructs.aws_eventbridge_stepfunctions._jsii": [
            "aws-eventbridge-stepfunctions@2.13.0.jsii.tgz"
        ],
        "aws_solutions_constructs.aws_eventbridge_stepfunctions": [
            "py.typed"
        ]
    },
    "python_requires": "~=3.7",
    "install_requires": [
        "aws-cdk-lib>=2.25.0, <3.0.0",
        "aws-solutions-constructs.core==2.13.0",
        "constructs>=10.0.0, <11.0.0",
        "jsii>=1.63.2, <2.0.0",
        "publication>=0.0.3",
        "typeguard~=2.13.3"
    ],
    "classifiers": [
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: JavaScript",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Typing :: Typed",
        "License :: OSI Approved"
    ],
    "scripts": []
}
"""
)

with open("README.md", encoding="utf8") as fp:
    kwargs["long_description"] = fp.read()


setuptools.setup(**kwargs)
